==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Send");
define("_URL","Internetadresse");
define("_PRINTER","Printervenlig side");
define("_FRIEND","Send denne nyhed til en ven");
define("_YOURNAME","Dit navn");
define("_OK","Ok!");
define("_RELATED","Relaterede links");
define("_MOREABOUT","Mere om");
define("_NEWSBY","Artikler af");
define("_MOSTREAD","Mest lste artikel om");
define("_READMORE","Ls mere...");
define("_BYTESMORE","bytes mere");
define("_COMMENTSQ","kommentr?");
define("_COMMENT","kommentar");
define("_CONFIGURE","Indstillinger");
define("_LOGINCREATE","Log ind / Bliv bruger");
define("_THRESHOLD","Laveste score");
define("_NOCOMMENTS","Ingen kommentarer");
define("_NESTED","Indrykket");
define("_FLAT","I rkkeflge");
define("_THREAD","Trdet");
define("_OLDEST","ldste frst");
define("_NEWEST","Nyeste frst");
define("_HIGHEST","Hjeste score frst");
define("_COMMENTSWARNING","Alle kommentarer tilhrer indsenderen. Vi er ikke ansvarlige for indholdet og kan ikke tages som udtryk for vores synspunkter.");
define("_SCORE","Hits:");
define("_USERINFO","Brugerinfo");
define("_READREST","Ls resten af denne kommentar...");
define("_REPLY","Svar til denne");
define("_REPLYMAIN","Send kommentar");
define("_NOSUBJECT","Intet emne");
define("_NOANONCOMMENTS","Anonyme kan ikke skrive kommentarer. Vr venlig at <a href=\"modules.php?name=Your_Account\">oprette</a> dig som bruger.");
define("_PARENT","Forrige");
define("_ROOT","Rod");
define("_UCOMMENT","Kommentar");
define("_ALLOWEDHTML","Tilladte HTML-koder:");
define("_POSTANON","Anonymt indlg");
define("_EXTRANS","Extrans (html-koder i teksten)");
define("_HTMLFORMATED","HTML-formateret");
define("_PLAINTEXT","Almindelig tekstformat");
define("_ONN",", som skriver...");
define("_SUBJECT","Emne");
define("_COMMENTREPLY","Send kommentar");
define("_COMREPLYPRE","Gennemse din kommentar");
define("_NOTRIGHT","Der er problemer med at analysere variablen i denne funktion. Denne besked er blot for at forhindre tingene i at blive forkludrede.");
define("_SENDAMSG","Send en besked");
define("_YOUSENDSTORY","Du nsker at sende denne artikel");
define("_TOAFRIEND","til en ven:");
define("_FYOURNAME","Dit navn:");
define("_FYOUREMAIL","Din e-mailadresse:");
define("_FFRIENDNAME","Din vens navn:");
define("_FFRIENDEMAIL","Din vens e-mailadresse:");
define("_INTERESTING","En interssant artikel p");
define("_HELLO","Hej");
define("_YOURFRIEND","Din ven");
define("_CONSIDERED","fandt denne artikel interessant, og nskede at sende den til dig.");
define("_FDATE","Dato:");
define("_FTOPIC","Emne:");
define("_YOUCANREAD","Du kan lse andre interessante artikler p");
define("_FSTORY","Artiklen");
define("_HASSENT","er blevet sendt til");
define("_THANKS","Tak!");
define("_RECOMMEND","Tip en ven om dette website.");
define("_PDATE","Dato:");
define("_PTOPIC","Emne:");
define("_COMESFROM","Denne artikel kommer fra");
define("_THEURL","Internetadressen til denne artikel er:");
define("_PREVIEW","Gennemse");
define("_NEWUSER","Ny bruger");
define("_OPTIONS","Valg");
define("_REFRESH","Genopfrisk");
define("_ADD","Opret");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Send");
define("_URL","Internetadresse");
define("_PRINTER","Printervenlig side");
define("_FRIEND","Send denne nyhed til en ven");
define("_YOURNAME","Dit navn");
define("_OK","Ok!");
define("_RELATED","Relaterede links");
define("_MOREABOUT","Mere om");
define("_NEWSBY","Artikler af");
define("_MOSTREAD","Mest lste artikel om");
define("_READMORE","Ls mere...");
define("_BYTESMORE","bytes mere");
define("_COMMENTSQ","kommentr?");
define("_COMMENT","kommentar");
define("_CONFIGURE","Indstillinger");
define("_LOGINCREATE","Log ind / Bliv bruger");
define("_THRESHOLD","Laveste score");
define("_NOCOMMENTS","Ingen kommentarer");
define("_NESTED","Indrykket");
define("_FLAT","I rkkeflge");
define("_THREAD","Trdet");
define("_OLDEST","ldste frst");
define("_NEWEST","Nyeste frst");
define("_HIGHEST","Hjeste score frst");
define("_COMMENTSWARNING","Alle kommentarer tilhrer indsenderen. Vi er ikke ansvarlige for indholdet og kan ikke tages som udtryk for vores synspunkter.");
define("_SCORE","Hits:");
define("_USERINFO","Brugerinfo");
define("_READREST","Ls resten af denne kommentar...");
define("_REPLY","Svar til denne");
define("_REPLYMAIN","Send kommentar");
define("_NOSUBJECT","Intet emne");
define("_NOANONCOMMENTS","Anonyme kan ikke skrive kommentarer. Vr venlig at <a href=\"modules.php?name=Your_Account\">oprette</a> dig som bruger.");
define("_PARENT","Forrige");
define("_ROOT","Rod");
define("_UCOMMENT","Kommentar");
define("_ALLOWEDHTML","Tilladte HTML-koder:");
define("_POSTANON","Anonymt indlg");
define("_EXTRANS","Extrans (html-koder i teksten)");
define("_HTMLFORMATED","HTML-formateret");
define("_PLAINTEXT","Almindelig tekstformat");
define("_ONN",", som skriver...");
define("_SUBJECT","Emne");
define("_COMMENTREPLY","Send kommentar");
define("_COMREPLYPRE","Gennemse din kommentar");
define("_NOTRIGHT","Der er problemer med at analysere variablen i denne funktion. Denne besked er blot for at forhindre tingene i at blive forkludrede.");
define("_SENDAMSG","Send en besked");
define("_YOUSENDSTORY","Du nsker at sende denne artikel");
define("_TOAFRIEND","til en ven:");
define("_FYOURNAME","Dit navn:");
define("_FYOUREMAIL","Din e-mailadresse:");
define("_FFRIENDNAME","Din vens navn:");
define("_FFRIENDEMAIL","Din vens e-mailadresse:");
define("_INTERESTING","En interssant artikel p");
define("_HELLO","Hej");
define("_YOURFRIEND","Din ven");
define("_CONSIDERED","fandt denne artikel interessant, og nskede at sende den til dig.");
define("_FDATE","Dato:");
define("_FTOPIC","Emne:");
define("_YOUCANREAD","Du kan lse andre interessante artikler p");
define("_FSTORY","Artiklen");
define("_HASSENT","er blevet sendt til");
define("_THANKS","Tak!");
define("_RECOMMEND","Tip en ven om dette website.");
define("_PDATE","Dato:");
define("_PTOPIC","Emne:");
define("_COMESFROM","Denne artikel kommer fra");
define("_THEURL","Internetadressen til denne artikel er:");
define("_PREVIEW","Gennemse");
define("_NEWUSER","Ny bruger");
define("_OPTIONS","Valg");
define("_REFRESH","Genopfrisk");
define("_ADD","Opret");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
